import { Query } from '@/api/webApi'
import { CommonData } from '~/common'
import * as _ from 'lodash'

export enum showTimeMsg {
  HourlyPeak, //小时峰值
  WaybillTrend, //运单趋势
  NodePeak, //节点峰值
  AirlineTraffic, //航司运量
  AirlineAbnormal, //航班预警报警
}

export function usePublic() {
  const optionLeft = {
    tooltip: {
      trigger: 'axis',
    },
    legend: {
      show: true,
      top: 0,
      left: '30%',
      icon: 'roundRect',
      textStyle: {
        color: '#698dc3',
      },
    },
    grid: {
      left: '5%',
      right: '5%',
      bottom: '0%',
      top: '17%',
      containLabel: true,
    },
    color: ['#F5BB3D', '#73D970', '#6A9DD9'],
    xAxis: {
      type: 'category',
      boundaryGap: true,
      data: [
        '0:00',
        '2:00',
        '4:00',
        '6:00',
        '8:00',
        '10:00',
        '12:00',
        '14:00',
        '16:00',
        '18:00',
        '20:00',
        '22:00',
      ],
      axisLine: {
        show: true,
        lineStyle: {
          color: '#8897BC',
        },
      },
      axisTick: {
        show: false,
      },
      axisLabel: {
        color: '#8897BC',
      },
    },
    yAxis: [
      {
        type: 'value',
        axisLabel: {
          color: '#8897BC',
          formatter: function (item) {
            return item / 10000 + '万'
          },
        },
        splitLine: {
          lineStyle: {
            type: 'dashed',
            color: 'rgba(196,194,225, 0.54)',
          },
        },
        name: '单',
      },
      {
        type: 'value',
        axisLabel: {
          color: '#8897BC',
        },
        splitLine: {
          lineStyle: {
            type: 'dashed',
            color: 'rgba(196,194,225, 0.54)',
          },
        },
        name: '吨',
      },
    ],
    series: [
      {
        name: '运单/单',
        type: 'line',
        symbol: 'none',
        key: 'bagsnum',
        yAxisIndex: 0,
        data: [120, 132, 101, 134, 90, 230, 210, 132, 101, 134, 90, 230],
        areaStyle: {
          color: {
            type: 'linear',
            x: 0,
            y: 0,
            x2: 0,
            y2: 1,
            colorStops: [
              {
                offset: 0,
                color: 'rgba(125,72,255,0.5)',
              },
              {
                offset: 1,
                color: 'rgba(0,180,255,0.01)',
              },
            ],
            global: false,
          },
        },
      },
      {
        name: '重量/吨',
        type: 'line',
        symbol: 'none',
        yAxisIndex: 1,
        key: 'passengers',
        data: [220, 182, 191, 234, 290, 330, 310, 132, 101, 134, 90, 230],
        areaStyle: {
          color: {
            type: 'linear',
            x: 0,
            y: 0,
            x2: 0,
            y2: 1,
            colorStops: [
              {
                offset: 0,
                color: 'rgba(125,72,255,0.5)',
              },
              {
                offset: 1,
                color: 'rgba(0,180,255,0.01)',
              },
            ],
            global: false,
          },
        },
      },
    ],
  }
  const airlineAbnormalBaggage = {
    component: 'commonChartsBar',
    option: {
      baseOption: {
        tooltip: {
          trigger: 'axis',
          valueFormatter: function (value) {
            return value + '单'
          },
        },
        legend: {
          data: ['报警', '预警'],
          right: '20%',
          textStyle: {
            color: '#8897BC',
          },
          // top:"-10"
        },
        color: ['#EC3B71', '#E5B35C'],
        grid: {
          bottom: '10%',
          left: '5%',
          right: '1%',
          top: '17%',
        },
        xAxis: {
          data: ['卸机', '机下交接', '货站交接', '提取'],
          axisLine: {
            show: true,
            lineStyle: {
              color: '#8897BC',
            },
          },
          axisTick: {
            show: false,
          },
          axisLabel: {
            color: '#8897BC',
          },
        },
        yAxis: {
          type: 'value',
          axisLabel: {
            color: '#8897BC',
          },
          splitLine: {
            lineStyle: {
              type: 'dashed',
              color: 'rgba(196,194,225, 0.54)',
            },
          },
          name: '单',
        },
        series: [
          {
            name: '报警',
            type: 'bar',
            data: [0, 0, 0, 0],
          },
          {
            name: '预警',
            type: 'bar',
            data: [0, 0, 0, 0],
          },
        ],
      },
    },
  }
  const airCompaneBaggage = {
    component: 'commonChartsBar',
    option: {
      baseOption: {
        tooltip: {
          trigger: 'axis',
        },
        legend: {
          data: ['运单/单', '重量/吨'],
          right: '20%',
          textStyle: {
            color: '#8897BC',
          },
        },
        color: ['#51DEE9', '#4C88E1'],
        grid: {
          bottom: '10%',
          left: '13%',
          right: '8%',
          top: '17%',
        },
        xAxis: {
          data: ['国航', '南航', '深航', '东航', '海航', '国泰', '川航'],
          axisLine: {
            show: true,
            lineStyle: {
              color: '#8897BC',
            },
          },
          axisTick: {
            show: false,
          },
          axisLabel: {
            color: '#8897BC',
          },
        },
        yAxis: [
          {
            type: 'value',
            axisLabel: {
              color: '#8897BC',
              formatter: function (item) {
                return item / 10000 + '万'
              },
            },
            splitLine: {
              lineStyle: {
                type: 'dashed',
                color: 'rgba(196,194,225, 0.54)',
              },
            },
            name: '单',
          },
          {
            type: 'value',
            axisLabel: {
              color: '#8897BC',
            },
            splitLine: {
              lineStyle: {
                type: 'dashed',
                color: 'rgba(196,194,225, 0.54)',
              },
            },
            name: '吨',
          },
        ],
        series: [
          {
            name: '运单/单',
            type: 'bar',
            data: [12, 10, 15, 11, 16, 4, 6],
            yAxisIndex: 0,
          },
          {
            name: '重量/吨',
            type: 'bar',
            data: [11, 15, 17, 8, 1, 4, 6],
            yAxisIndex: 1,
          },
        ],
      },
    },
  }
  const airStutas = {
    component: 'commonChartsBar',
    option: {
      baseOption: {
        // legend: {
        //   data: ['2020年', '2021年'],
        //   right:"20",
        //   textStyle:{
        //     color: "#8897BC"
        //   }
        //   // top:"-10"
        // },
        tooltip: {
          trigger: 'axis',
          valueFormatter: function (value) {
            return value + '单'
          },
        },
        color: ['#51DEE9', '#4C88E1'],
        grid: {
          bottom: '10%',
          left: '5%',
          right: '1%',
          top: '17%',
        },
        xAxis: {
          data: ['机下交接', '货站交接', '理货'],
          axisLine: {
            show: true,
            lineStyle: {
              color: '#8897BC',
            },
          },
          axisTick: {
            show: false,
          },
          axisLabel: {
            color: '#8897BC',
          },
        },
        yAxis: {
          type: 'value',
          axisLabel: {
            color: '#8897BC',
          },
          splitLine: {
            lineStyle: {
              type: 'dashed',
              color: 'rgba(196,194,225, 0.54)',
            },
          },
          name: '单',
        },
        series: [
          {
            type: 'bar',
            data: [12, 10, 15],
          },
        ],
      },
    },
  }
  const nodeEfficiency = {
    component: 'commonChartsLine',
    option: {
      tooltip: {
        trigger: 'axis',
        valueFormatter: function (value) {
          return value + '秒'
        },
      },
      legend: {
        top: '1%',
        right: '5%',
        data: ['平均时间', '最长时间', '最短时间'],
        itemWidth: 25,
        itemHeight: 14,
      },
      grid: {
        bottom: '10%',
        left: '7%',
        right: '1%',
        top: '17%',
      },
      color: ['#3ca4fc', '#f1ce7c', '#36ccba'],
      xAxis: {
        axisLabel: {
          interval: 0,
        },
        data: ['卸机', '机下交接', '货站交接', '提取'],
      },
      yAxis: {
        type: 'value',
        axisLabel: {
          color: '#8897BC',
        },
        splitLine: {
          lineStyle: {
            type: 'dashed',
            color: 'rgba(196,194,225, 0.54)',
          },
        },
        name: '单位：秒',
      },
      series: [
        {
          name: '平均时间',
          type: 'line',
          smooth: true,
          stack: '',
          areaStyle: {
            opacity: 0,
          },
          data: [
            4016,
            4652,
            1570,
            6334,
            12052,
            3115,
            10604,
            12733,
            14533,
            2464,
            4168,
            3844,
          ],
        },
        {
          name: '最长时间',
          type: 'line',
          smooth: true,
          stack: '',
          areaStyle: {
            opacity: 0,
          },
          data: [
            4558,
            770,
            11745,
            2699,
            11205,
            6497,
            1544,
            1555,
            4181,
            447,
            60,
            9804,
          ],
        },
        {
          name: '最短时间',
          type: 'line',
          smooth: true,
          stack: '',
          areaStyle: {
            opacity: 0,
          },
          data: [
            14240,
            3190,
            1699,
            14446,
            11349,
            11182,
            14829,
            11740,
            2418,
            4824,
            9707,
            8126,
          ],
        },
      ],
    },
  }
  const node = ['卸机', '机下交接', '货站交接', '提取']

  const hours = Array.from({ length: 24 }, (v, i) => i + 1)
  const hourPeak = {
    component: 'commonChartsScatter',
    option: {
      tooltip: {
        trigger: 'axis',
        valueFormatter: function (value) {
          return value + '单'
        },
      },
      title: node.map((month, index) => ({
        top: ((index + 0.5) * 100) / 4 - 3 + '%',
        text: month,
        textStyle: {
          fontSize: 12,
          fontWeight: 'normal',
          color: '#698dc3',
        },
      })),
      singleAxis: node.map((month, index) => ({
        type: 'category',
        data: hours,
        top: ((index + 0.5) * 100) / 4 - 3 + '%',
        height: 100 / 4 - 5 + '%',
        left: '12%',
        right: '1%',
        axisTick: {
          show: false,
        },
        splitLine: {
          show: false,
        },
      })),
      series: node.map((month, index) => ({
        singleAxisIndex: index,
        coordinateSystem: 'singleAxis',
        type: 'scatter',
        data: [
          3,
          6,
          1,
          4,
          0,
          4,
          2,
          5,
          4,
          4,
          6,
          2,
          0,
          3,
          1,
          6,
          6,
          1,
          0,
          3,
          6,
          3,
          0,
          5,
        ],
        symbolSize: function (dataItem) {
          return dataItem * 3
        },
      })),
    },
  }
  const getPublicData = async (id: number, times?: any[]) => {
    try {
      const {
        code,
        returnData: { listValues },
        message,
      } = await Query<CommonData>({
        id,
        dataContent: times,
      })
      if (Number(code) !== 0) {
        throw new Error(message || '失败')
      } else {
        return listValues
      }
    } catch (error) {
      console.error(error)
    }
  }
  const geoCoordMap = {
    上海: [121.4648, 31.2891],
    东莞: [113.8953, 22.901],
    东营: [118.7073, 37.5513],
    中山: [113.4229, 22.478],
    临汾: [111.4783, 36.1615],
    临沂: [118.3118, 35.2936],
    丹东: [124.541, 40.4242],
    丽水: [119.5642, 28.1854],
    乌鲁木齐: [87.9236, 43.5883],
    佛山: [112.8955, 23.1097],
    保定: [115.0488, 39.0948],
    兰州: [103.5901, 36.3043],
    包头: [110.3467, 41.4899],
    北京: [116.4551, 40.2539],
    北海: [109.314, 21.6211],
    南京: [118.8062, 31.9208],
    南宁: [108.479, 23.1152],
    南昌: [116.0046, 28.6633],
    南通: [121.1023, 32.1625],
    厦门: [118.1689, 24.6478],
    台州: [121.1353, 28.6688],
    合肥: [117.29, 32.0581],
    呼和浩特: [111.4124, 40.4901],
    咸阳: [108.4131, 34.8706],
    哈尔滨: [127.9688, 45.368],
    唐山: [118.4766, 39.6826],
    嘉兴: [120.9155, 30.6354],
    大同: [113.7854, 39.8035],
    大连: [122.2229, 39.4409],
    天津: [117.4219, 39.4189],
    太原: [112.3352, 37.9413],
    威海: [121.9482, 37.1393],
    宁波: [121.5967, 29.6466],
    宝鸡: [107.1826, 34.3433],
    宿迁: [118.5535, 33.7775],
    常州: [119.4543, 31.5582],
    广州: [113.5107, 23.2196],
    廊坊: [116.521, 39.0509],
    延安: [109.1052, 36.4252],
    张家口: [115.1477, 40.8527],
    徐州: [117.5208, 34.3268],
    德州: [116.6858, 37.2107],
    惠州: [114.6204, 23.1647],
    成都: [103.9526, 30.7617],
    扬州: [119.4653, 32.8162],
    承德: [117.5757, 41.4075],
    拉萨: [91.1865, 30.1465],
    无锡: [120.3442, 31.5527],
    日照: [119.2786, 35.5023],
    昆明: [102.9199, 25.4663],
    杭州: [119.5313, 29.8773],
    枣庄: [117.323, 34.8926],
    柳州: [109.3799, 24.9774],
    株洲: [113.5327, 27.0319],
    武汉: [114.3896, 30.6628],
    汕头: [117.1692, 23.3405],
    江门: [112.6318, 22.1484],
    沈阳: [123.1238, 42.1216],
    沧州: [116.8286, 38.2104],
    河源: [114.917, 23.9722],
    泉州: [118.3228, 25.1147],
    泰安: [117.0264, 36.0516],
    泰州: [120.0586, 32.5525],
    济南: [117.1582, 36.8701],
    济宁: [116.8286, 35.3375],
    海口: [110.3893, 19.8516],
    淄博: [118.0371, 36.6064],
    淮安: [118.927, 33.4039],
    深圳: [114.5435, 22.5439],
    清远: [112.9175, 24.3292],
    温州: [120.498, 27.8119],
    渭南: [109.7864, 35.0299],
    湖州: [119.8608, 30.7782],
    湘潭: [112.5439, 27.7075],
    滨州: [117.8174, 37.4963],
    潍坊: [119.0918, 36.524],
    烟台: [120.7397, 37.5128],
    玉溪: [101.9312, 23.8898],
    珠海: [113.7305, 22.1155],
    盐城: [120.2234, 33.5577],
    盘锦: [121.9482, 41.0449],
    石家庄: [114.4995, 38.1006],
    福州: [119.4543, 25.9222],
    秦皇岛: [119.2126, 40.0232],
    绍兴: [120.564, 29.7565],
    聊城: [115.9167, 36.4032],
    肇庆: [112.1265, 23.5822],
    舟山: [122.2559, 30.2234],
    苏州: [120.6519, 31.3989],
    莱芜: [117.6526, 36.2714],
    菏泽: [115.6201, 35.2057],
    营口: [122.4316, 40.4297],
    葫芦岛: [120.1575, 40.578],
    衡水: [115.8838, 37.7161],
    衢州: [118.6853, 28.8666],
    西宁: [101.4038, 36.8207],
    西安: [109.1162, 34.2004],
    贵阳: [106.6992, 26.7682],
    连云港: [119.1248, 34.552],
    邢台: [114.8071, 37.2821],
    邯郸: [114.4775, 36.535],
    郑州: [113.4668, 34.6234],
    鄂尔多斯: [108.9734, 39.2487],
    重庆: [107.7539, 30.1904],
    金华: [120.0037, 29.1028],
    铜川: [109.0393, 35.1947],
    银川: [106.3586, 38.1775],
    镇江: [119.4763, 31.9702],
    长春: [125.8154, 44.2584],
    长沙: [113.0823, 28.2568],
    长治: [112.8625, 36.4746],
    阳泉: [113.4778, 38.0951],
    青岛: [120.4651, 36.3373],
    韶关: [113.7964, 24.7028],
  }
  const convertData = (data) => {
    const res: any = []
    for (let i = 0; i < data.length; i++) {
      const dataItem = data[i]
      const fromCoord = geoCoordMap[dataItem[0].name]
      const toCoord = geoCoordMap[dataItem[1].name]
      if (fromCoord && toCoord) {
        res.push({
          fromName: dataItem[0].name,
          toName: dataItem[1].name,
          coords: [fromCoord, toCoord],
          value: dataItem[1].value,
        })
      }
    }
    return res
  }
  const getMapData = (arr: any[]) => {
    const series: any = []
    const color = ['#a6c84c', '#ffa022', '#46bee9']
    const planePath =
      'path://M1705.06,1318.313v-89.254l-319.9-221.799l0.073-208.063c0.521-84.662-26.629-121.796-63.961-121.491c-37.332-0.305-64.482,36.829-63.961,121.491l0.073,208.063l-319.9,221.799v89.254l330.343-157.288l12.238,241.308l-134.449,92.931l0.531,42.034l175.125-42.917l175.125,42.917l0.531-42.034l-134.449-92.931l12.238-241.308L1705.06,1318.313z'
    arr.forEach(function (item: any, i) {
      //console.log(item,i);
      series.push(
        {
          name: item[0] + ' Top10',
          type: 'lines',
          zlevel: 1,
          effect: {
            show: true,
            period: 6,
            trailLength: 0.7,
            color: '#fff',
            symbolSize: 3,
          },
          lineStyle: {
            normal: {
              color: color[i],
              width: 0,
              curveness: 0.2,
            },
          },
          data: convertData(item[1]),
        },
        {
          name: item[0] + ' Top10',
          type: 'lines',
          zlevel: 2,
          symbol: ['none', 'arrow'],
          symbolSize: 10,
          effect: {
            show: true,
            period: 6,
            trailLength: 0,
            symbol: planePath,
            symbolSize: 15,
          },
          lineStyle: {
            normal: {
              color: color[i],
              width: 1,
              opacity: 0.6,
              curveness: 0.2,
            },
          },
          data: convertData(item[1]),
        },
        {
          name: item[0] + ' Top10',
          type: 'effectScatter',
          coordinateSystem: 'geo',
          zlevel: 2,
          rippleEffect: {
            brushType: 'stroke',
          },
          label: {
            normal: {
              show: true,
              position: 'right',
              formatter: '{b}',
            },
          },
          symbolSize: function (val) {
            return val[2] / 8
          },
          itemStyle: {
            normal: {
              color: color[i],
            },
          },
          data: item[1].map(function (dataItem) {
            return {
              name: dataItem[1].name,
              value: geoCoordMap[dataItem[1].name].concat([dataItem[1].value]),
            }
          }),
        }
      )
    })
    return series
  }
  return {
    optionLeft,
    airlineAbnormalBaggage,
    airCompaneBaggage,
    airStutas,
    nodeEfficiency,
    hourPeak,
    getPublicData,
    getMapData,
  }
}
